==> otyacraftengine-forge-2.4-sources.jar: dev/felnull/otyacraftengine/client/gui/screen/OEContainerBaseScreen.java <==
package dev.felnull.otyacraftengine.client.gui.screen;

import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.vertex.PoseStack;
import dev.felnull.otyacraftengine.inventory.OEBaseMenu;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.components.EditBox;
import net.minecraft.client.gui.components.events.GuiEventListener;
import net.minecraft.client.gui.screens.inventory.AbstractContainerScreen;
import net.minecraft.client.renderer.GameRenderer;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.entity.player.Inventory;

import java.util.UUID;

public abstract class OEContainerBaseScreen<T extends OEBaseMenu> extends AbstractContainerScreen<T> implements IInstructionScreen {
    protected static final Minecraft mc = Minecraft.m_91087_();
    protected final UUID id = UUID.randomUUID();
    protected int bgTextureWidth = 256;
    protected int bgTextureHeight = 256;

    public OEContainerBaseScreen(T abstractContainerMenu, Inventory inventory, Component component) {
        super(abstractContainerMenu, inventory, component);
    }


    @Override
    public void m_6305_(PoseStack poseStack, int i, int j, float f) {
        this.m_7333_(poseStack);
        super.m_6305_(poseStack, i, j, f);
        this.m_7025_(poseStack, i, j);
    }

    @Override
    protected void m_7286_(PoseStack poseStack, float f, int i, int j) {
        if (getBackGrandTexture() != null) {
            RenderSystem.m_157427_(GameRenderer::m_172817_);
            RenderSystem.m_157429_(1.0F, 1.0F, 1.0F, 1.0F);
            RenderSystem.m_157456_(0, getBackGrandTexture());
            m_93133_(poseStack, f_97735_, f_97736_, 0, 0, this.f_97726_, this.f_97727_, bgTextureWidth, bgTextureHeight);
        }
    }

    protected abstract ResourceLocation getBackGrandTexture();


    @Override
    public boolean m_7979_(double d, double e, int i, double f, double g) {
        boolean flag1 = super.m_7979_(d, e, i, f, g);
        boolean flag2 = this.m_7222_() != null && this.m_7282_() && i == 0 && this.m_7222_().m_7979_(d, e, i, f, g);
        return flag1 & flag2;
    }

    @Override
    protected void m_181908_() {
        super.m_181908_();
        for (GuiEventListener child : m_6702_()) {
            if (child instanceof EditBox editBox) {
                editBox.m_94120_();
            }
        }
    }

    @Override
    public boolean m_7933_(int i, int j, int k) {
        if (i == 256)
            mc.f_91074_.m_6915_();

        for (GuiEventListener child : m_6702_()) {
            if (child instanceof EditBox editBox) {
                if (editBox.m_7933_(i, j, k) || editBox.m_94204_())
                    return true;
            }
        }

        return super.m_7933_(i, j, k);
    }

    @Override
    public void onInstructionReturn(String name, int num, CompoundTag data) {

    }

    @Override
    public UUID getInstructionID() {
        return id;
    }
}

==> otyacraftengine-forge-3.0-sources.jar: dev/felnull/otyacraftengine/client/gui/screen/OEContainerBaseScreen.java <==
package dev.felnull.otyacraftengine.client.gui.screen;

import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.vertex.PoseStack;
import dev.felnull.otyacraftengine.inventory.OEBaseMenu;
import net.minecraft.client.Minecraft;
import net.minecraft.client.gui.components.EditBox;
import net.minecraft.client.gui.components.events.GuiEventListener;
import net.minecraft.client.gui.screens.inventory.AbstractContainerScreen;
import net.minecraft.client.renderer.GameRenderer;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.network.chat.Component;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.entity.player.Inventory;

import java.util.UUID;

public abstract class OEContainerBaseScreen<T extends OEBaseMenu> extends AbstractContainerScreen<T> implements IInstructionScreen, IOEBaseScreen {
    protected static final Minecraft mc = Minecraft.m_91087_();
    protected final UUID id = UUID.randomUUID();
    protected int bgTextureWidth = 256;
    protected int bgTextureHeight = 256;

    public OEContainerBaseScreen(T abstractContainerMenu, Inventory inventory, Component component) {
        super(abstractContainerMenu, inventory, component);
    }


    @Override
    public void m_6305_(PoseStack poseStack, int i, int j, float f) {
        this.m_7333_(poseStack);
        super.m_6305_(poseStack, i, j, f);
        this.m_7025_(poseStack, i, j);
    }

    @Override
    protected void m_7286_(PoseStack poseStack, float f, int i, int j) {
        if (getBackGrandTexture() != null) {
            RenderSystem.m_157427_(GameRenderer::m_172817_);
            RenderSystem.m_157429_(1.0F, 1.0F, 1.0F, 1.0F);
            RenderSystem.m_157456_(0, getBackGrandTexture());
            m_93133_(poseStack, f_97735_, f_97736_, 0, 0, this.f_97726_, this.f_97727_, bgTextureWidth, bgTextureHeight);
        }
    }

    protected abstract ResourceLocation getBackGrandTexture();


    @Override
    public boolean m_7979_(double d, double e, int i, double f, double g) {
        boolean flag1 = super.m_7979_(d, e, i, f, g);
        boolean flag2 = this.m_7222_() != null && this.m_7282_() && i == 0 && this.m_7222_().m_7979_(d, e, i, f, g);
        return flag1 & flag2;
    }

    @Override
    protected void m_181908_() {
        super.m_181908_();
        for (GuiEventListener child : m_6702_()) {
            if (child instanceof EditBox editBox) {
                editBox.m_94120_();
            }
        }
    }

    @Override
    public boolean m_7933_(int i, int j, int k) {
        if (i == 256)
            mc.f_91074_.m_6915_();

        for (GuiEventListener child : m_6702_()) {
            if (child instanceof EditBox editBox) {
                if (editBox.m_7933_(i, j, k) || editBox.m_94204_())
                    return true;
            }
        }

        return super.m_7933_(i, j, k);
    }

    @Override
    public void onInstructionReturn(String name, CompoundTag data) {

    }

    @Override
    public UUID getInstructionID() {
        return id;
    }
}
